/**
 * apeman task to babel cli commands.
 * @memberof module:apeman-task-babel/lib
 * @function define
 * @param {object} [options] - Optional settings.
 * @returns {function} - Defined task function.
 */

"use strict";

const argx = require('argx'),
    execcli = require('execcli'),
    objnest = require('objnest');

/** @lends define */
function define(src, options) {
    let args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    /**
     * Defined task.
     * @function task
     * @param {object} context - Apeman task context.
     * @param {function} callback - Callback when done.
     */
    function task(context, callback) {
        let logger = context.logger,
            verbose = context.verbose;
        define.babel([src].concat(options), {}, callback);
    }

    // Description of this task.
    task.$desc = "Execute babel command.";
    return task;
}

define.babel = function (args, options, callback) {
    execcli.npmBin('babel', args, Object.assign({
        notfound: 'try `npm install babel-cli -g`',
        search: [process.cwd(), __dirname]
    }, options), callback);
};

module.exports = define;
